#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Qt Modern Style
===============

A modern, clean, and professional Qt stylesheet with icons for
PyQt5/PyQt6/PySide2/PySide6 applications.

Basic Usage:
    >>> from PyQt5.QtWidgets import QApplication
    >>> import qt_modern_style
    >>>
    >>> app = QApplication([])
    >>> qt_modern_style.apply(app)

For more information, see: https://github.com/yourusername/qt-modern-style
"""

__version__ = "2.0.0"
__author__ = "Qt Modern Style Contributors"
__license__ = "MIT"

from .core import (
    apply,
    get_stylesheet,
    get_stylesheet_path,
    get_package_dir,
    load_resources,
    get_icon,
    get_icon_path,
    list_icons,
    list_base_icons,
    list_asset_icons,
)

__all__ = [
    "apply",
    "get_stylesheet",
    "get_stylesheet_path",
    "get_package_dir",
    "load_resources",
    "get_icon",
    "get_icon_path",
    "list_icons",
    "list_base_icons",
    "list_asset_icons",
    "__version__",
]
