# Qt Resources placeholder
# This file will be generated by the Qt resource compiler (pyrcc5, pyside6-rcc, etc.)
# or can be used as a fallback when resources are loaded directly from files.

# If you're using this package and icons are not loading via the Qt resource system,
# you can use the get_icon() and get_icon_path() functions which load icons directly
# from the file system.

pass
