#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Setup script for qt-modern-style package.
This file is kept for backwards compatibility with older pip versions.
"""

from setuptools import setup

if __name__ == "__main__":
    setup()
